summaryrefslogtreecommitdiffstats
path: root/src/storage/phrase_index.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/storage/phrase_index.h')
-rw-r--r--src/storage/phrase_index.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/src/storage/phrase_index.h b/src/storage/phrase_index.h
index bb3f84b..4deac16 100644
--- a/src/storage/phrase_index.h
+++ b/src/storage/phrase_index.h
@@ -530,13 +530,13 @@ public:
bool merge(guint8 phrase_index, MemoryChunk * log);
/**
* FacadePhraseIndex::compat:
* @returns: whether the compat operation is successful.
*
* Compat all sub phrase index memory usage.
*
*/
- bool compat();
+ bool compact();
/**
* FacadePhraseIndex::get_sub_phrase_range:
@@ -530,13 +530,13 @@ public:
bool merge(guint8 phrase_index, MemoryChunk * log);
/**
- * FacadePhraseIndex::compat:
- * @returns: whether the compat operation is successful.
+ * FacadePhraseIndex::compact:
+ * @returns: whether the compact operation is successful.
*
* Compat all sub phrase index memory usage.